@@ -2,7 +2,7 @@
 # deltree: recursively removes file and directory,
 # trying to handle permissions and other complications.
 
-# Copyright (C) 2013-2025 Free Software Foundation, Inc.
+# Copyright (C) 2013-2014 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,9 +15,10 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-use strict; use warnings;
+use strict;
+use warnings FATAL => 'all';
 use File::Path qw/rmtree/;
 
 my $exit_status = 0;
