@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,11 +18,10 @@
 # are used, even when dependency tracking is disabled.
 
 required='cc lex'
-. ./defs || Exit 1
+. test-init.sh
 
 cat >>configure.ac <<\END
 AC_PROG_CC
-AM_PROG_CC_C_O
 AC_PROG_LEX
 AC_OUTPUT
 END
