@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2001-2012 Free Software Foundation, Inc.
+# Copyright (C) 2001-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # *_SOURCES
 # Richard Boulton <richard@tartarus.org>
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -41,7 +41,7 @@ $AUTOMAKE
 grep '.\$(CXXLINK)' Makefile.in
 
 # We should not see these patterns:
-grep '.\$(FLINK)' Makefile.in && Exit 1
-grep '.\$(LINK)'  Makefile.in && Exit 1
+grep '.\$(FLINK)' Makefile.in && exit 1
+grep '.\$(LINK)'  Makefile.in && exit 1
 
-Exit 0
+exit 0
