@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 1998-2012 Free Software Foundation, Inc.
+# Copyright (C) 1998-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 # Test to make sure the C++ linker is used when appropriate.
 # Matthew D. Langston <langston@SLAC.Stanford.EDU>
 
-. ./defs || Exit 1
+. test-init.sh
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -40,7 +40,7 @@ $AUTOMAKE
 grep '.\$(CXXLINK)' Makefile.in
 
 # We should not see these patterns:
-grep '.\$(F77LINK)' Makefile.in && Exit 1
-grep '.\$(LINK)'    Makefile.in && Exit 1
+grep '.\$(F77LINK)' Makefile.in && exit 1
+grep '.\$(LINK)'    Makefile.in && exit 1
 
-Exit 0
+exit 0
