@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2025 Free Software Foundation, Inc.
+# Copyright (C) 2002-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,7 +11,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 use Automake::Version;
 
@@ -92,11 +92,6 @@ my @tests = (
   ['1.5.1a', '1.5.1f', -1],
   ['1.5.1f', '1.5.1a', 1],
   ['1.5.1f', '1.5.1f', 0],
-# with four-part numeric versions, starting 2024
-  ['1.17.0.91', '1.17.0.91', 0],
-  ['1.17.0.91', '1.17.0.92', -1],
-  ['1.17.0.91', '1.17.1', -1],
-  ['1.17.0.91', '1.17', 1],
 # special exceptions
   ['1.6-p5a', '1.6.5a', 0],
   ['1.6', '1.6-p5a', -1],
@@ -108,10 +103,27 @@ my @tests = (
 );
 
 my @bad_versions = (
-  '', 'a', '1', '1a', '-1.2'
+  '', 'a', '1', '1a', '1.2.3.4', '-1.2'
 );
 
 test_version_compare (@{$_}) foreach @tests;
 test_bad_versions ($_) foreach @bad_versions;
 
 exit $failed;
+
+### Setup "GNU" style for perl-mode and cperl-mode.
+## Local Variables:
+## perl-indent-level: 2
+## perl-continued-statement-offset: 2
+## perl-continued-brace-offset: 0
+## perl-brace-offset: 0
+## perl-brace-imaginary-offset: 0
+## perl-label-offset: -2
+## cperl-indent-level: 2
+## cperl-brace-offset: 0
+## cperl-continued-brace-offset: 0
+## cperl-label-offset: -2
+## cperl-extra-newline-before-brace: t
+## cperl-merge-trailing-else: nil
+## cperl-continued-statement-offset: 2
+## End:
