@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
 # Test on automake options '--print-data-dir' and '--print-script-dir'.
 
 am_create_testdir=empty
-. ./defs || Exit 1
+. test-init.sh
 
-libdir=`$AUTOMAKE --print-libdir` || Exit 1
-case $libdir in /*);; *) Exit 1;; esac
+libdir=$($AUTOMAKE --print-libdir) || exit 1
+case $libdir in /*);; *) exit 1;; esac
 test -d "$libdir"
 test "$libdir" = "$am_pkgvdatadir"
 test "$libdir" = "$am_scriptdir"
