@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2012 Free Software Foundation, Inc.
+# Copyright (C) 2011-2014 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,10 +17,10 @@
 # Test remake rules when an m4 file gets removed and the macros it
 # defined get inlined into the caller.  Try with both an indirect
 # call and a direct one.  This can be seen as testing the "deleted
-# header file" issue w.r.t. aclocal.m4 dependencies.  See also related
-# test 'acloca22.sh'.
+# header file" issue w.r.t. aclocal.m4 dependencies.  See also
+# related test 'aclocal-deleted-header.sh'.
 
-. ./defs || exit 1
+. test-init.sh
 
 cat >> configure.ac <<'END'
 FOO_MACRO
